@@ -12,6 +12,7 @@ use DateTime;
 use DateTime::Format::Duration;
 use Cwd;
 use File::Path qw(make_path);
+use File::Spec;
 
 use Moose;
 use Moose::Util::TypeConstraints;
@@ -28,7 +29,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '1.3';
+our $VERSION = '1.4';
 
 =head1 SYNOPSIS
 
@@ -52,9 +53,17 @@ has 'infile' => (
     is => 'rw',
     isa => 'Str',
     required => 1,
-    documentation => q{File of commands separated by newline. The command 'wait' indicates all previous commands should finish before starting the next one.}
+    documentation => q{File of commands separated by newline. The command 'wait' indicates all previous commands should finish before starting the next one.},
+    trigger => \&_set_infile,
 );
 
+sub _set_infile{
+    my($self, $infile) = @_;
+
+    $infile = File::Spec->rel2abs($infile);
+    $self->{infile} = $infile;
+}
+
 =head2 outdir
 
 Directory to write out files and logs.
@@ -66,9 +75,18 @@ has 'outdir' => (
     isa => 'Str',
     required => 1,
     default => sub {return getcwd() },
-    documentation => q{Directory to write out files.}
+    documentation => q{Directory to write out files.},
+    trigger => \&_set_outdir,
 );
 
+sub _set_outdir{
+    my($self, $outdir) = @_;
+
+    make_path($outdir) if ! -d $outdir;
+    $outdir = File::Spec->rel2abs($outdir);
+    $self->{outdir} = $outdir;
+}
+
 =head2 logdir
 
 Pattern to use to write out logs directory. Defaults to outdir/prunner_current_date_time/log1 .. log2 .. log3.
